==> jc-1.4.0.tar.gz: gnu/java/text/CharacterBreakIterator.h <==
// public class gnu.java.text.CharacterBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class cc1c09db590c666a gnu_java_text_CharacterBreakIterator
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_CharacterBreakIterator_H_
#define _JC_gnu_java_text_CharacterBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_CharacterBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_CharacterBreakIterator$sub_refs	_jc_gnu_java_text_CharacterBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs	_jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$refs	_jc_gnu_java_text_CharacterBreakIterator$refs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$nonrefs	_jc_gnu_java_text_CharacterBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$object	_jc_gnu_java_text_CharacterBreakIterator$object;

typedef struct _jc_gnu_java_text_CharacterBreakIterator$fields_struct	_jc_gnu_java_text_CharacterBreakIterator$fields_struct;
typedef const struct _jc_gnu_java_text_CharacterBreakIterator$vmethods	_jc_gnu_java_text_CharacterBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_CharacterBreakIterator$vtable	_jc_gnu_java_text_CharacterBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_CharacterBreakIterator$vtype	_jc_gnu_java_text_CharacterBreakIterator$vtype;

// Class fields structure
struct _jc_gnu_java_text_CharacterBreakIterator$fields_struct {
	jint	LBase;
	jint	LCount;
	jint	TBase;
	jint	TCount;
	jint	VBase;
	jint	VCount;
	jint	highSurrogateEnd;
	jint	highSurrogateStart;
	jint	lowSurrogateEnd;
	jint	lowSurrogateStart;
};
extern _jc_gnu_java_text_CharacterBreakIterator$fields_struct _jc_gnu_java_text_CharacterBreakIterator$class_fields;

// Constructors
extern void _jc_gnu_java_text_CharacterBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);
extern void _jc_gnu_java_text_CharacterBreakIterator$method$_init$9470daccaa32e246(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_CharacterBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isHighSurrogate$b666b1ad3658877c(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isL$b968db5129617c79(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isLVT$c302d80ab3308469(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isLowSurrogate$13c8cf645260c8c6(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isT$d75477d52ec6488f(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isV$c90a577dcdf6b77a(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
extern jint _jc_gnu_java_text_CharacterBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);
extern jint _jc_gnu_java_text_CharacterBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isHighSurrogate$b666b1ad3658877c;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isL$b968db5129617c79;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isLVT$c302d80ab3308469;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isLowSurrogate$13c8cf645260c8c6;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isT$d75477d52ec6488f;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isV$c90a577dcdf6b77a;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$previous$9ade62028ea90005;

// Virtual methods structure
struct _jc_gnu_java_text_CharacterBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);
	jboolean	(*isHighSurrogate$b666b1ad3658877c)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
	jboolean	(*isL$b968db5129617c79)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
	jboolean	(*isLVT$c302d80ab3308469)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
	jboolean	(*isLowSurrogate$13c8cf645260c8c6)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
	jboolean	(*isT$d75477d52ec6488f)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
	jboolean	(*isV$c90a577dcdf6b77a)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar);
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *);
};

// Vtable
struct _jc_gnu_java_text_CharacterBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_CharacterBreakIterator$vmethods	gnu_java_text_CharacterBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_CharacterBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_CharacterBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_CharacterBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_CharacterBreakIterator$refs {
    _jc_gnu_java_text_CharacterBreakIterator$sub_refs	gnu_java_text_CharacterBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_CharacterBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs	gnu_java_text_CharacterBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_CharacterBreakIterator$object {
	_jc_gnu_java_text_CharacterBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_CharacterBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_CharacterBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_CharacterBreakIterator$vtype _jc_gnu_java_text_CharacterBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_CharacterBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_CharacterBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_CharacterBreakIterator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/text/CharacterBreakIterator.h <==
// public class gnu.java.text.CharacterBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class cc1c09db590c666a gnu_java_text_CharacterBreakIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_CharacterBreakIterator_H_
#define _JC_gnu_java_text_CharacterBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_CharacterBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_CharacterBreakIterator$sub_refs	_jc_gnu_java_text_CharacterBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs	_jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$refs	_jc_gnu_java_text_CharacterBreakIterator$refs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$nonrefs	_jc_gnu_java_text_CharacterBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_CharacterBreakIterator$object	_jc_gnu_java_text_CharacterBreakIterator$object;

typedef struct _jc_gnu_java_text_CharacterBreakIterator$fields_struct	_jc_gnu_java_text_CharacterBreakIterator$fields_struct;
typedef const struct _jc_gnu_java_text_CharacterBreakIterator$vmethods	_jc_gnu_java_text_CharacterBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_CharacterBreakIterator$vtable	_jc_gnu_java_text_CharacterBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_CharacterBreakIterator$vtype	_jc_gnu_java_text_CharacterBreakIterator$vtype;

// Class fields structure
struct _jc_gnu_java_text_CharacterBreakIterator$fields_struct {
	jint	LBase;
	jint	LCount;
	jint	TBase;
	jint	TCount;
	jint	VBase;
	jint	VCount;
	jint	highSurrogateEnd;
	jint	highSurrogateStart;
	jint	lowSurrogateEnd;
	jint	lowSurrogateStart;
};
extern _jc_gnu_java_text_CharacterBreakIterator$fields_struct _jc_gnu_java_text_CharacterBreakIterator$class_fields;

// Constructors
extern void _jc_gnu_java_text_CharacterBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_text_CharacterBreakIterator$method$_init$9470daccaa32e246(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_CharacterBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isHighSurrogate$b666b1ad3658877c(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isL$b968db5129617c79(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isLVT$c302d80ab3308469(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isLowSurrogate$13c8cf645260c8c6(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isT$d75477d52ec6488f(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_CharacterBreakIterator$method$isV$c90a577dcdf6b77a(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_CharacterBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_CharacterBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isHighSurrogate$b666b1ad3658877c;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isL$b968db5129617c79;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isLVT$c302d80ab3308469;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isLowSurrogate$13c8cf645260c8c6;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isT$d75477d52ec6488f;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$isV$c90a577dcdf6b77a;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_CharacterBreakIterator$method_info$previous$9ade62028ea90005;

// Virtual methods structure
struct _jc_gnu_java_text_CharacterBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*isHighSurrogate$b666b1ad3658877c)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isL$b968db5129617c79)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isLVT$c302d80ab3308469)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isLowSurrogate$13c8cf645260c8c6)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isT$d75477d52ec6488f)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isV$c90a577dcdf6b77a)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_CharacterBreakIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_text_CharacterBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_CharacterBreakIterator$vmethods	gnu_java_text_CharacterBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_CharacterBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_CharacterBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_CharacterBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_CharacterBreakIterator$refs {
    _jc_gnu_java_text_CharacterBreakIterator$sub_refs	gnu_java_text_CharacterBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_CharacterBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_CharacterBreakIterator$sub_nonrefs	gnu_java_text_CharacterBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_CharacterBreakIterator$object {
	_jc_gnu_java_text_CharacterBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_CharacterBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_CharacterBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_CharacterBreakIterator$vtype _jc_gnu_java_text_CharacterBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_CharacterBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_CharacterBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_CharacterBreakIterator_H_ */
